<?xml version="1.0" encoding="ISO-8859-15"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
    <xsl:output method="text" indent="no" encoding="ISO-8859-1"	media-type="text/plain" />
    <xsl:strip-space elements="*" />


    <xsl:key name="aDate" match="Veranstaltung" use="START_DATUM" />
    <xsl:key name="aPlace" match="Veranstaltung" use="_place_NAME" />
    <xsl:variable name="stdFont">
        <!-- Standard-Font fr alle Inhalte in der Tabelle -->
        <xsl:text>{font size=10 face=arial}</xsl:text>
    </xsl:variable>
        
    <xsl:template match="/root/Export">
        <!-- Definition von Kopf und Fusszeile -->
        {header}<xsl:value-of select="Veranstaltung/_user_REALNAME[1]"/>{/header}
        {footer}{font color=#333333 size=8 face=arial}powered by www.evangelische-termine.de{/font}{/footer}
        
        {table width=100% border=1}
        <xsl:call-template name="makeTableHeader" />
        <xsl:call-template name="main" />
        {/table}
        
    </xsl:template>
    
    <!-- Sortiere und gruppiere Veranstaltungen nach Datum -->
    <xsl:template name="main">
        <xsl:for-each select="//Veranstaltung">
            <xsl:sort select="START" order="ascending" />
            <xsl:if test="not(preceding::START_DATUM = START_DATUM)">
                <xsl:choose>
                    <xsl:when test="WOCHENTAG_START_LANG='Sonntag'">
                        <xsl:text>{tr bgcolor=20}</xsl:text>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:text>{tr}</xsl:text>
                    </xsl:otherwise>
                </xsl:choose>
                <xsl:call-template name="perDateProcess">
                    <xsl:with-param name="forDate" select="START_DATUM"/>
                </xsl:call-template>
                <xsl:text>{/tr}</xsl:text>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>
    
    <!-- Template erhlt Start-Datum (forDate) und gibt Orte aus -->
    <xsl:template name="perDateProcess">
        <xsl:param name="forDate"/>
        
        <xsl:text>{td}</xsl:text>
        <xsl:value-of select="$stdFont" />
        <xsl:value-of select="WOCHENTAG_START_LANG"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="$forDate" />
        <xsl:text>{/font}{/td}</xsl:text>
        
        <xsl:call-template name="perPlaceProcess">
            <xsl:with-param name="forDate" select="$forDate" />
        </xsl:call-template>
        
    </xsl:template>
    
    <!-- Template gibt alle Termine fr ein gegebenes Datum nach Orten sortiert aus -->
    <xsl:template name="perPlaceProcess">
        <xsl:param name="forDate"/>
        
        <xsl:for-each select="//Veranstaltung">
            <xsl:sort select="_place_NAME" />
            <xsl:if test="not(preceding::_place_NAME = _place_NAME)">
                <xsl:text>{td}</xsl:text>
                <xsl:call-template name="perDateAndPlaceProcess">
                    <xsl:with-param name="forDate" select="$forDate" />
                    <xsl:with-param name="forPlace" select="_place_NAME" />
                </xsl:call-template>
                <xsl:text>{/td}</xsl:text>
            </xsl:if>
        </xsl:for-each>
        
    </xsl:template>
    
    <!-- Template gibt alle Termine an gegebenem Datum fr gegebenen Ort aus -->
    <xsl:template name="perDateAndPlaceProcess">
        <xsl:param name="forDate"/>
        <xsl:param name="forPlace"/>
        
        <xsl:for-each select="key('aDate', $forDate)">
            <xsl:sort select="START_UHRZEIT" />
            <xsl:if test="_place_NAME = $forPlace">
                <xsl:text>{p}</xsl:text>
                <xsl:value-of select="$stdFont" />
                <xsl:value-of select="START_UHRZEIT"/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="_event_TITLE" />
                <xsl:text>{/font}</xsl:text>
            </xsl:if>
        </xsl:for-each>
    </xsl:template>
    
    <!-- Template erzeugt Titelzeile -->
    <xsl:template name="makeTableHeader">
        <xsl:text>{tr}{td}{/td}</xsl:text>
        <xsl:for-each select="//Veranstaltung"> 
            <xsl:sort select="_place_NAME" />
            <xsl:if test="not(preceding::_place_NAME=_place_NAME)">
                <xsl:text>{td align=center valign=top}{b}</xsl:text>
                <xsl:value-of select="$stdFont" />
                <xsl:value-of select="_place_NAME" />
                <xsl:text>{/font}{/b}{/td}</xsl:text>
            </xsl:if>
        </xsl:for-each>
        <xsl:text>{/tr}</xsl:text>
    </xsl:template>
    
</xsl:stylesheet>
